==> AnyEvent-HTTPBenchmark-0.05.tar.gz: AnyEvent-HTTPBenchmark-0.05/lib/AnyEvent/HTTPBenchmark.pm <==
package AnyEvent::HTTPBenchmark;

use warnings;
use strict;

=head1 NAME

AnyEvent::HTTPBenchmark - The tool to make benchmark good and easy!

=head1 VERSION

Version 0.05

=cut

our $VERSION = '0.05';


=head1 SYNOPSIS

Quick summary of what the module does.

Perhaps a little code snippet.

    use AnyEvent::HTTPBenchmark;

   
=head1 EXPORT

A list of functions that can be exported.  You can delete this section
if you don't export anything, such as for a purely object-oriented module.

=head1 SUBROUTINES/METHODS

=head2 function1

=cut

sub function1 {
}

=head2 function2

=cut

sub function2 {
	#under construction
}

=head1 AUTHOR

Naim Shafiev, C<< <naim at cpan.org> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-anyevent-httpbenchmark at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=AnyEvent-HTTPBenchmark>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc AnyEvent::HTTPBenchmark


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=AnyEvent-HTTPBenchmark>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/AnyEvent-HTTPBenchmark>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/AnyEvent-HTTPBenchmark>

=item * Search CPAN

L<http://search.cpan.org/dist/AnyEvent-HTTPBenchmark/>

=back


=head1 ACKNOWLEDGEMENTS


=head1 LICENSE AND COPYRIGHT

Copyright 2010 Naim Shafiev.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; version 2 dated June, 1991 or at your option
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

A copy of the GNU General Public License is available in the source tree;
if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.


=cut

1; # End of AnyEvent::HTTPBenchmark

==> AnyEvent-HTTPBenchmark-0.06.tar.gz: AnyEvent-HTTPBenchmark-0.06/lib/AnyEvent/HTTPBenchmark.pm <==
package AnyEvent::HTTPBenchmark;

use warnings;
use strict;

=head1 NAME

AnyEvent::HTTPBenchmark - The tool to make benchmark good and easy!

=head1 VERSION

Version 0.06

=cut

our $VERSION = '0.06';


=head1 SYNOPSIS
The apache benchmark (ab) , siege, jmeter and etc, are sometimes awesome to make http-load testing. But if 
you want make some non-traditional test they are not good decision.This module try to help you in this case.
Currently implemented just test utility , not a library .

	benchmark.pl --url http://example.com -n 100 -c 10 -v 
   
=head1 EXPORT

Currently no export functions are implemented.

=head1 SUBROUTINES/METHODS

=head2 function1

=cut

sub function1 {
}

=head2 function2

=cut

sub function2 {
	#under construction
}

=head1 AUTHOR

Naim Shafiev, C<< <naim at cpan.org> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-anyevent-httpbenchmark at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=AnyEvent-HTTPBenchmark>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc AnyEvent::HTTPBenchmark


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=AnyEvent-HTTPBenchmark>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/AnyEvent-HTTPBenchmark>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/AnyEvent-HTTPBenchmark>

=item * Search CPAN

L<http://search.cpan.org/dist/AnyEvent-HTTPBenchmark/>

=back


=head1 ACKNOWLEDGEMENTS


=head1 LICENSE AND COPYRIGHT

Copyright 2010 Naim Shafiev.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; version 2 dated June, 1991 or at your option
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

A copy of the GNU General Public License is available in the source tree;
if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.


=cut

1; # End of AnyEvent::HTTPBenchmark
